From: Rodrigo Vivi <rodrigo.v...@intel.com>

[ Upstream commit 8a734b9359cfa1bdb805f5ca23e20bd99dd18a0a ]

A simple lazy buggy copy and paste of the PVC comment has brought
the attention to the incorrect masks of the PVC register for RPa
and RPe. So, let's fix them all.

Cc: Lucas De Marchi <lucas.demar...@intel.com>
Cc: Vinay Belgaumkar <vinay.belgaum...@intel.com>
Reviewed-by: Vinay Belgaumkar <vinay.belgaum...@intel.com>
Link: 
https://patchwork.freedesktop.org/patch/msgid/20250109195219.658557-1-rodrigo.v...@intel.com
Signed-off-by: Rodrigo Vivi <rodrigo.v...@intel.com>
Signed-off-by: Sasha Levin <sas...@kernel.org>
---
 drivers/gpu/drm/xe/xe_guc_pc.c | 22 ++++++++++++----------
 1 file changed, 12 insertions(+), 10 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_guc_pc.c b/drivers/gpu/drm/xe/xe_guc_pc.c
index f382f5d53ca8b..2276d85926fcb 100644
--- a/drivers/gpu/drm/xe/xe_guc_pc.c
+++ b/drivers/gpu/drm/xe/xe_guc_pc.c
@@ -371,16 +371,17 @@ static void tgl_update_rpa_value(struct xe_guc_pc *pc)
        u32 reg;
 
        /*
         * For PVC we still need to use fused RP1 as the approximation for RPe
         * For other platforms than PVC we get the resolved RPe directly from
         * PCODE at a different register
         */
-       if (xe->info.platform == XE_PVC)
+       if (xe->info.platform == XE_PVC) {
                reg = xe_mmio_read32(&gt->mmio, PVC_RP_STATE_CAP);
-       else
+               pc->rpa_freq = REG_FIELD_GET(RP0_MASK, reg) * 
GT_FREQUENCY_MULTIPLIER;
+       } else {
                reg = xe_mmio_read32(&gt->mmio, FREQ_INFO_REC);
-
-       pc->rpa_freq = REG_FIELD_GET(RPA_MASK, reg) * GT_FREQUENCY_MULTIPLIER;
+               pc->rpa_freq = REG_FIELD_GET(RPA_MASK, reg) * 
GT_FREQUENCY_MULTIPLIER;
+       }
 }
 
 static void tgl_update_rpe_value(struct xe_guc_pc *pc)
@@ -394,12 +395,13 @@ static void tgl_update_rpe_value(struct xe_guc_pc *pc)
         * For other platforms than PVC we get the resolved RPe directly from
         * PCODE at a different register
         */
-       if (xe->info.platform == XE_PVC)
+       if (xe->info.platform == XE_PVC) {
                reg = xe_mmio_read32(&gt->mmio, PVC_RP_STATE_CAP);
-       else
+               pc->rpe_freq = REG_FIELD_GET(RP1_MASK, reg) * 
GT_FREQUENCY_MULTIPLIER;
+       } else {
                reg = xe_mmio_read32(&gt->mmio, FREQ_INFO_REC);
-
-       pc->rpe_freq = REG_FIELD_GET(RPE_MASK, reg) * GT_FREQUENCY_MULTIPLIER;
+               pc->rpe_freq = REG_FIELD_GET(RPE_MASK, reg) * 
GT_FREQUENCY_MULTIPLIER;
+       }
 }
 
 static void pc_update_rp_values(struct xe_guc_pc *pc)
@@ -371,16 +371,17 @@ static void tgl_update_rpa_value(struct xe_guc_pc *pc)
 
        /*
-        * For PVC we still need to use fused RP1 as the approximation for RPe
-        * For other platforms than PVC we get the resolved RPe directly from
+        * For PVC we still need to use fused RP0 as the approximation for RPa
+        * For other platforms than PVC we get the resolved RPa directly from
         * PCODE at a different register
         */
-- 
2.39.5

Reply via email to